"""
All API wrapper classes can be imported from here.
"""
from .trace_moe import TraceMoeAPI
from .anime_facts_rest_api import AnimeFactsRestAPI
from .animechan import AnimechanAPI
from .waifu_pics import WaifuPicsAPI
from .studio_ghibli_api import StudioGhibliAPI
from .kyoko import KyokoAPI
from .animu import AnimuAPI
from .hmtai import HmtaiAPI
from .nekos_life import NekosLifeAPI
from .nekobot import NekoBotAPI
from .neko_love import NekoLoveAPI
from .nekos_moe import NekosMoeAPI
from .nekos_best import NekosBest
from .waifu_im import WaifuImAPI
from .nekos_api import NekosAPI
